@@ -1,6 +1,7 @@
 import importlib
 import os
 import re
+from types import ModuleType
 from typing import Any, Callable
 import click
 from python_project_manager import Config
@@ -41,10 +42,8 @@ def sanitize_string_for_module(string: str) -> str:
 def pass_command_to_engine(_command: str, _method: Callable[..., bool], **_kwargs) -> bool:
     try:
     # built-in engines
-        if Config.get('engine', '').startswith('ppm-builtin-setuptools'):
-            engine = importlib.import_module('python_project_manager.builtin_engines.builtin_setuptools')
-        else:
-            engine = importlib.import_module(sanitize_string_for_file(Config.get('engine', _kwargs.get('__engine', ''))))
+        
+        engine = get_engine(_kwargs.get('_engine', Config.get('engine')))
         method: Callable[..., bool] = getattr(engine, _command, None)
         if method:
             keep_processing = method(_method, **_kwargs)
@@ -60,13 +59,24 @@ def pass_command_to_engine(_command: str, _method: Callable[..., bool], **_kwarg
         else:
             raise e
 
+def get_engine(engine_name: str) -> ModuleType | None:
+    if engine_name == None or engine_name == '':
+        return None
+    match engine_name:
+        case 'ppm-builtin-setuptools': # Built-in engine
+            return importlib.import_module('.builtin_engines.builtin_setuptools', package='python_project_manager')
+        case _: # External engine
+            return importlib.import_module(sanitize_string_for_file(engine_name))
+        
 @click.group()
 def cli():
     pass
 
 @cli.command()
 @click.argument('project_name', type=str, required=True)
-@click.option('--engine', '-e', type=str, default='ppm-builtin-setuptools', help='Choose the engine \'module\' to use')
+@click.option('--engine', '-e', type=str, default='',
+    help="""Choose the engine \'module\' to use.
+    Defaults include \'ppm-builtin-setuptools\'""")
 @click.option('--force', '-f', is_flag=True, help='Force initialization of the project')
 # @click.option('--python', '-p', type=str, default='', help='Python version to use')
 def init(project_name: str, engine: str, force: bool) -> None:
@@ -74,8 +84,8 @@ def init(project_name: str, engine: str, force: bool) -> None:
     <project_name> - Name of the project to be setup
     '''
     # Verify project can be initialized with the given parameters
-    if pass_command_to_engine('verify', _verify,
-        force=force, project_name=project_name, __engine=engine):
+    if pass_command_to_engine('verify', _verify, _engine=engine,
+        force=force, project_name=project_name, engine=engine):
 
         # Even though the looks like it belongs in the '_init' method,
         # it is placed here so external engines can not stop nessary files from being created
@@ -108,12 +118,8 @@ def _verify(**kwargs) -> bool:
         return False
     
     # Check if the engine if not empty and not a built-in engine
-    if engine != '' and not engine.startswith('ppm-builtin'):
-        try:
-            importlib.import_module(sanitize_string_for_file(Config.get('engine')))
-        except Exception as e:
-            print(f"Engine '{engine}': Error: {e}")
-            return False
+    if engine != '':
+        get_engine(engine)
 
     return True
 
@@ -162,7 +168,7 @@ def _run(**kwargs) -> bool:
                     # Remove targ_dir from python_path
                     cli_command = cli_command.replace(python_path[0],python_path[0].replace(targ_dir[0], ""))
                     if targ_dir[0][:-1] == Config.get('test_dir'):
-                        cli_command = f'set PYTHONPATH=C:\{Config.get('src_dir')};%PYTHONPATH% && {cli_command}'
+                        cli_command = f'set PYTHONPATH=C:\\{Config.get('src_dir')};%PYTHONPATH% && {cli_command}'
                         
     os.chdir(cwd) # Change the current working directory
     os.system(f'{VENV} && {cli_command}') # Run the command
@@ -262,15 +268,24 @@ def install(args, help, dev) -> None:
     '''
     Uses pip's 'install' command
     '''
+    # Create the command
+    cmd = f'{VENV} && pip install {" ".join(args)}'.strip()
+
+    # If 'pip install pip' is passed, install pip
+    if cmd == f'{VENV} && pip install pip':
+        os.system(f'{VENV} && python -m ensurepip')
+        return
+
+    # Use the help command if the '--help' flag is passed
     if help:
         os.system(f'{VENV} && pip install --help')
         return
-    
-    cmd = f'{VENV} && pip install {" ".join(args)}'
 
-    if cmd.strip() == f'{VENV} && pip install':
+    # If no arguments are passed, install the requirements
+    if cmd == f'{VENV} && pip install':
         os.system(f'{VENV} && pip install -r requirements.txt -r requirements-dev.txt')
 
+    # Otherwise, install the packages
     try:
         output = os.popen(cmd)
 
@@ -278,6 +293,7 @@ def install(args, help, dev) -> None:
         for line in output:
             print(line.strip())
             if 'Successfully installed' in line:
+                # Update the requirements file
                 update_requirements(line.strip(), dev)
 
         # Close the output stream
